# tractor-js-file-transformer

A bunch of AST manipulation utilities for [**tractor**](https://github.com/TradeMe/tractor).

[![Greenkeeper badge](https://badges.greenkeeper.io/phenomnomnominal/tractor-js-file-transformer.svg)](https://greenkeeper.io/)
[![npm version](https://img.shields.io/npm/v/tractor-js-file-transformer.svg)](https://www.npmjs.com/package/tractor-js-file-transformer)
[![Coveralls](https://img.shields.io/coveralls/phenomnomnominal/tractor-js-file-transformer.svg)](https://coveralls.io/github/phenomnomnominal/tractor-js-file-transformer)

## API:

### `transformIdentifiers`:

> Renames an identifier within an AST

> #### Arguments:
> * `file: `[`JavaScriptFile`](https://github.com/phenomnomnominal/tractor-server#JavaScriptFile) - The JavaScript file to manipulate
> * `oldName: string` - the name of the identifiers that you want to change
> * `newName: string` - the new name for the identifiers
> * `contextName?: string` - a context for selecting the elements, which should be a [**esquery**](https://github.com/estools/esquery) query

> #### Usage:
> ```javascript
import { transformIdentifiers } from 'tractor-js-file-transformer';

>// Replace all instances of `foo` with `bar`
transformIdentifiers(file, 'foo', 'bar');

>// Replace all instances of `var foo` with `var bar`
transformIdentifiers(file, 'foo', 'bar', 'VariableDeclarator');
```

### `transformMetadata`:

> Renames an metadata object stored in the first comment of a JS file

> #### Arguments:
> * `file: `[`JavaScriptFile`](https://github.com/phenomnomnominal/tractor-server#JavaScriptFile) - The JavaScript file to manipulate
> * `oldName: string` - the name of the identifiers that you want to change
> * `newName: string` - the new name for the identifiers
> * `type?: string` - the type of the metadata object

> #### Usage:
> ```javascript
import { transformMetadata } from 'tractor-js-file-transformer';

>// Changes metadata comment from
// /* { "name": "foo" } */
// to
// /* { "name": "bar" } */
transformMetadata(file, 'foo', 'bar');

>// Changes metadata comment from
// /* { "items": [{ "name": "foo" }, { "name": "baz" }] } */
// to
// /* { "items": [{ "name": "bar" }, { "name": "baz" }] } */
transformMetadata(file, 'foo', 'bar', 'items');
```

### `transformRequirePaths`:

> Updates the path in a `require` call when a file moves.

> #### Arguments:
> * `file: `[`JavaScriptFile`](https://github.com/phenomnomnominal/tractor-server#JavaScriptFile) - The JavaScript file to manipulate
> * `options: `[`TransformRequireOptions`](https://github.com/phenomnomnominal/tractor-js-file-transformer#TransformRequireOptions)

> #### Usage:
> ```javascript
import { transformRequirePaths } from 'tractor-js-file-transformer';

> // Replace
// `require('../../../that/goes/to/another/file')`
// with
// `require('../../../that/goes/to/a/new/file')`
transformRequirePaths(file, {
    fromPath: '/some/path/to/a/file',
    oldToPath: '/some/path/that/goes/to/another/file',
    newToPath: '/some/path/that/goes/to/a/new/file'
});

## Interfaces:

### TransformRequireOptions:

```javascript
interface TransformRequireOptions {
    oldFromPath?: string;
    newFromPath?: string;
    fromPath?: string;
    oldToPath?: string;
    newToPath?: string;
    toPath?: string;
}
