'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.transformRequirePaths = transformRequirePaths;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _esquery = require('esquery');

var _esquery2 = _interopRequireDefault(_esquery);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Utilities:
function transformRequirePaths(file, options) {
    var oldFromPath = options.oldFromPath,
        newFromPath = options.newFromPath;

    if (!(oldFromPath && newFromPath)) {
        oldFromPath = newFromPath = options.fromPath;
    }

    var oldToPath = options.oldToPath,
        newToPath = options.newToPath;

    if (!(oldToPath && newToPath)) {
        oldToPath = newToPath = options.toPath;
    }

    var oldRequirePath = getRelativeRequirePath(_path2.default.dirname(oldFromPath), oldToPath);
    var newRequirePath = getRelativeRequirePath(_path2.default.dirname(newFromPath), newToPath);
    updatePaths(file, oldRequirePath, newRequirePath);
}

// Dependencies:


function getRelativeRequirePath(from, to) {
    var relativePath = _path2.default.relative(from, to).replace(/\\/g, '/');
    return (/^\./.test(relativePath) ? relativePath : './' + relativePath
    );
}

function updatePaths(file, oldRequirePath, newRequirePath) {
    var query = 'CallExpression[callee.name="require"] Literal[value="' + oldRequirePath + '"]';

    (0, _esquery2.default)(file.ast, query).forEach(function (requirePathLiteral) {
        requirePathLiteral.value = newRequirePath;
        requirePathLiteral.raw = '\'' + newRequirePath + '\'';
    });
}